@@ -32,7 +32,6 @@
 #include <string.h>
 
 #include "gupnp-didl-lite-resource.h"
-#include "gupnp-dlna-private.h"
 #include "xml-util.h"
 
 #define SEC_PER_MIN 60
@@ -638,18 +637,6 @@ gupnp_didl_lite_resource_class_init (GUPnPDIDLLiteResourceClass *klass)
                                    G_PARAM_STATIC_BLURB));
 }
 
-/**
- * gupnp_didl_lite_resource_new
- *
- * Return value: A new #GUPnPDIDLLiteResource object. Unref after usage.
- **/
-GUPnPDIDLLiteResource *
-gupnp_didl_lite_resource_new (void)
-{
-        return g_object_new (GUPNP_TYPE_DIDL_LITE_RESOURCE,
-                             NULL);
-}
-
 /**
  * gupnp_didl_lite_resource_new_from_xml
  * @xml_node: The pointer to 'res' node in XML document
@@ -702,6 +689,9 @@ gupnp_didl_lite_resource_get_uri (GUPnPDIDLLiteResource *resource)
 {
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource), NULL);
 
+        if (G_UNLIKELY (resource->priv->xml_node->children == NULL))
+                return NULL;
+
         return (const char *) resource->priv->xml_node->children->content;
 }
 
@@ -756,18 +746,6 @@ gupnp_didl_lite_resource_get_protocol_info (GUPnPDIDLLiteResource *resource)
                            error->message);
 
                 g_error_free (error);
-        } else {
-                /* Try guessing the DLNA profile if not available */
-                if (gupnp_protocol_info_get_dlna_profile (info) == NULL) {
-                        const char *dlna_profile;
-                        const char *mime_type;
-
-                        mime_type = gupnp_protocol_info_get_mime_type (info);
-                        dlna_profile = dlna_guess_profile (resource, mime_type);
-
-                        gupnp_protocol_info_set_dlna_profile (info,
-                                                              dlna_profile);
-                }
         }
 
         resource->priv->protocol_info = info;
@@ -1014,11 +992,9 @@ gupnp_didl_lite_resource_set_import_uri (GUPnPDIDLLiteResource *resource,
 /**
  * gupnp_didl_lite_resource_set_protocol_info
  * @resource: A #GUPnPDIDLLiteResource
- * @protocol: The protocol string
+ * @info: The protocol string
  *
- * Set the protocol info associated with the @resource. If the
- * #GUPnPProtocolInfo:dlna-profile of @info is not set, an attempt will be made 
- * to guess it for you.
+ * Set the protocol info associated with the @resource.
  *
  * Return value: None.
  **/
@@ -1031,17 +1007,6 @@ gupnp_didl_lite_resource_set_protocol_info (GUPnPDIDLLiteResource *resource,
         g_return_if_fail (GUPNP_IS_DIDL_LITE_RESOURCE (resource));
         g_return_if_fail (GUPNP_IS_PROTOCOL_INFO (info));
 
-        /* Try guessing the DLNA profile if not available */
-        if (gupnp_protocol_info_get_dlna_profile (info) == NULL) {
-                const char *dlna_profile;
-                const char *mime_type;
-
-                mime_type = gupnp_protocol_info_get_mime_type (info);
-                dlna_profile = dlna_guess_profile (resource, mime_type);
-
-                gupnp_protocol_info_set_dlna_profile (info, dlna_profile);
-        }
-
         str = gupnp_protocol_info_to_string (info);
         xmlSetProp (resource->priv->xml_node,
                     (unsigned char *) "protocolInfo",
@@ -1122,7 +1087,7 @@ gupnp_didl_lite_resource_set_duration (GUPnPDIDLLiteResource *resource,
         else {
                 char *str;
 
-                str = g_strdup_printf ("%ld:%.2ld:%.2ld",
+                str = g_strdup_printf ("%ld:%.2ld:%.2ld.00",
                                        duration / (60 * 60),
                                        (duration / 60) % 60,
                                        duration % 60);
@@ -1361,7 +1326,7 @@ gupnp_didl_lite_resource_set_height (GUPnPDIDLLiteResource *resource,
 /**
  * gupnp_didl_lite_resource_set_color_depth
  * @resource: A #GUPnPDIDLLiteResource
- * @height: The color-depth
+ * @color_depth: The color-depth
  *
  * Set the color-depth of this image/video resource. Passing a negative number
  * will unset this property.
